pub struct FieldDef {
pub name: String,
pub data_type: DataType,
pub meaning: FieldMeaning,
pub required: bool,
pub is_list: bool,
pub readable: bool,
pub writable: bool,
}Expand description
A field definition within a service projection.
Fields
name: Stringdata_type: DataTypemeaning: FieldMeaningrequired: boolis_list: boolreadable: boolwritable: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for FieldDef
impl<'de> Deserialize<'de> for FieldDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FieldDef
impl JsonSchema for FieldDef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Eq for FieldDef
impl StructuralPartialEq for FieldDef